/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangebuyer.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * The configuration data for an Ad Exchange performance report list. TODO(nathanbullock): need to
 * add some release tests before releasing this. https://sites.google.com/a/google.com/adx-
 * integration/Home/engineering/binary-releases/rtb-api-release
 * https://cs.corp.google.com/#piperdepot/google3/contentads/adx/tools/rtb_api/adxrtb.py
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Buyer API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PerformanceReport extends GenericJson {

  /**
   * The quota limits for this account.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("QuotaConfiguredLimit")
  private Double quotaConfiguredLimit;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("QuotaThrottledLimit")
  private Double quotaThrottledLimit;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The Nth percentile round trip latency(ms) as perceived from Google servers for the duration
   * period covered by the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double latency50thPercentile;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double latency85thPercentile;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double latency95thPercentile;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double noQuotaInRegion;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double outOfQuota;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double pixelMatchRequests;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double pixelMatchResponses;

  /**
   * The trading location of this data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String region;

  /**
   * Timestamp of the starting time of this performance data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long timestamp;

  /**
   * The quota limits for this account.
   * The value returned may be {@code null}.
   */
  public Double getQuotaConfiguredLimit() {
    return quotaConfiguredLimit;
  }

  /**
   * The quota limits for this account.
   * The value set may be {@code null}.
   */
  public PerformanceReport setQuotaConfiguredLimit(Double quotaConfiguredLimit) {
    this.quotaConfiguredLimit = quotaConfiguredLimit;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getQuotaThrottledLimit() {
    return quotaThrottledLimit;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setQuotaThrottledLimit(Double quotaThrottledLimit) {
    this.quotaThrottledLimit = quotaThrottledLimit;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public PerformanceReport setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The Nth percentile round trip latency(ms) as perceived from Google servers for the duration
   * period covered by the report.
   * The value returned may be {@code null}.
   */
  public Double getLatency50thPercentile() {
    return latency50thPercentile;
  }

  /**
   * The Nth percentile round trip latency(ms) as perceived from Google servers for the duration
   * period covered by the report.
   * The value set may be {@code null}.
   */
  public PerformanceReport setLatency50thPercentile(Double latency50thPercentile) {
    this.latency50thPercentile = latency50thPercentile;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getLatency85thPercentile() {
    return latency85thPercentile;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setLatency85thPercentile(Double latency85thPercentile) {
    this.latency85thPercentile = latency85thPercentile;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getLatency95thPercentile() {
    return latency95thPercentile;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setLatency95thPercentile(Double latency95thPercentile) {
    this.latency95thPercentile = latency95thPercentile;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getNoQuotaInRegion() {
    return noQuotaInRegion;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setNoQuotaInRegion(Double noQuotaInRegion) {
    this.noQuotaInRegion = noQuotaInRegion;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getOutOfQuota() {
    return outOfQuota;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setOutOfQuota(Double outOfQuota) {
    this.outOfQuota = outOfQuota;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getPixelMatchRequests() {
    return pixelMatchRequests;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setPixelMatchRequests(Double pixelMatchRequests) {
    this.pixelMatchRequests = pixelMatchRequests;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public Double getPixelMatchResponses() {
    return pixelMatchResponses;
  }

  /**

   * The value set may be {@code null}.
   */
  public PerformanceReport setPixelMatchResponses(Double pixelMatchResponses) {
    this.pixelMatchResponses = pixelMatchResponses;
    return this;
  }

  /**
   * The trading location of this data.
   * The value returned may be {@code null}.
   */
  public String getRegion() {
    return region;
  }

  /**
   * The trading location of this data.
   * The value set may be {@code null}.
   */
  public PerformanceReport setRegion(String region) {
    this.region = region;
    return this;
  }

  /**
   * Timestamp of the starting time of this performance data.
   * The value returned may be {@code null}.
   */
  public Long getTimestamp() {
    return timestamp;
  }

  /**
   * Timestamp of the starting time of this performance data.
   * The value set may be {@code null}.
   */
  public PerformanceReport setTimestamp(Long timestamp) {
    this.timestamp = timestamp;
    return this;
  }

}
